@@ -76,7 +76,7 @@ main ()
   if (NULL == daemon)
     return 1;
 
-  getchar ();
+  (void) getchar ();
 
   MHD_stop_daemon (daemon);
   return 0;
